@@ -778,6 +778,11 @@ void wikitohtml(TCXSTR *rbuf, const char *str, const char *id, const char *buri,
         obj = true;
         line++;
       }
+      bool vdo = false;
+      if(*line == '*') {
+        vdo = true;
+        line++;
+      }
       const char *align = "normal";
       int lv = 3;
       if(*line == '<'){
@@ -883,6 +888,18 @@ void wikitohtml(TCXSTR *rbuf, const char *str, const char *id, const char *buri,
             tcxstrprintf(rbuf, "object:%d:%@", imgcnt, name);
           }
           tcxstrprintf(rbuf, "</object>");
+        } else if(vdo){
+          tcxstrprintf(rbuf, "<video src=\"%@\"", url);
+          if(width > 0) tcxstrprintf(rbuf, " width=\"%d%s\"", width, wratio ? "%" : "");
+          if(height > 0) tcxstrprintf(rbuf, " height=\"%d%s\"", height, hratio ? "%" : "");
+          tcxstrprintf(rbuf, " preload=\"metadata\"");
+          tcxstrprintf(rbuf, " controls=\"controls\"");
+          if(alt){
+            tcxstrprintf(rbuf, " alt=\"%@\"", alt);
+          } else {
+            tcxstrprintf(rbuf, " alt=\"video:%d:%@\"", imgcnt, name);
+          }
+          tcxstrprintf(rbuf, " />");
         } else {
           tcxstrprintf(rbuf, "<img src=\"%@\"", url);
           if(width > 0) tcxstrprintf(rbuf, " width=\"%d%s\"", width, wratio ? "%" : "");
